==> nextcloud-25.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_status/l10n/nl.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Recente statussen",
    "In a meeting" : "In een vergadering",
    "Commuting" : "Woon-werk",
    "Out sick" : "Ziek",
    "Vacationing" : "Op vakantie",
    "Working remotely" : "Thuiswerken",
    "In a call" : "In gesprek",
    "User status" : "Gebruikersstatus",
    "View profile" : "Bekijk profiel",
    "Clear status after" : "Maak de status leeg na",
    "What is your status?" : "Wat is jouw status?",
    "Set status" : "Instellen status",
    "Online status" : "Online status",
    "Status message" : "Statusbericht",
    "Clear status message" : "Opruimen statusbericht",
    "Set status message" : "Instellen statusbericht",
    "There was an error saving the status" : "Er is een fout opgetreden bij het bewaren van de status",
    "There was an error clearing the status" : "Er is een fout opgetreden bij het leegmaken van de status",
    "No recent status changes" : "Geen recente statuswijzigingen",
    "Away" : "Afwezig",
    "Do not disturb" : "Niet storen",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Niet schoonmaken",
    "Today" : "Vandaag",
    "This week" : "Deze week",
    "Online" : "Online",
    "Invisible" : "Verborgen",
    "Offline" : "Off-line",
    "There was an error saving the new status" : "Er is een fout opgetreden bij het bewaren van de nieuwe status",
    "30 minutes" : "30 minuten",
    "1 hour" : "1 uur",
    "4 hours" : "4 uur",
    "Mute all notifications" : "Onderdruk alle meldingen",
    "Appear offline" : "Toon afwezig",
    "Clear status message after" : "Statusbericht wissen na"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_status/l10n/nl.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Recente statussen",
    "In a meeting" : "In een vergadering",
    "Commuting" : "Woon-werk",
    "Out sick" : "Ziek",
    "Vacationing" : "Op vakantie",
    "Working remotely" : "Thuiswerken",
    "In a call" : "In gesprek",
    "User status" : "Gebruikersstatus",
    "View profile" : "Bekijk profiel",
    "Clear status after" : "Maak de status leeg na",
    "What is your status?" : "Wat is jouw status?",
    "Set status" : "Status instellen",
    "Online status" : "Online status",
    "Status message" : "Statusbericht",
    "Clear status message" : "Statusbericht wissen",
    "Set status message" : "Statusbericht instellen",
    "There was an error saving the status" : "Er is een fout opgetreden bij het bewaren van de status",
    "There was an error clearing the status" : "Er is een fout opgetreden bij het leegmaken van de status",
    "No recent status changes" : "Geen recente statuswijzigingen",
    "Away" : "Afwezig",
    "Do not disturb" : "Niet storen",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Niet schoonmaken",
    "Today" : "Vandaag",
    "This week" : "Deze week",
    "Online" : "Online",
    "Invisible" : "Verborgen",
    "Offline" : "Off-line",
    "There was an error saving the new status" : "Er is een fout opgetreden bij het bewaren van de nieuwe status",
    "30 minutes" : "30 minuten",
    "1 hour" : "1 uur",
    "4 hours" : "4 uur",
    "Mute all notifications" : "Onderdruk alle meldingen",
    "Appear offline" : "Toon afwezig"
},
"nplurals=2; plural=(n != 1);");
